Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type WorkerPool ¶
type WorkerPool struct {
// contains filtered or unexported fields
}
WorkerPool represents a pool of workers that can process jobs concurrently
func NewWorkerPool ¶
func NewWorkerPool(workerCount int) *WorkerPool
NewWorkerPool creates a new worker pool with the specified number of workers
Click to show internal directories.
Click to hide internal directories.