fields

package
v0.2.28 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 3, 2026 License: MIT Imports: 1 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func LookupByTag

func LookupByTag(obj any, tagType, tagValue string) (any, bool)

LookupByTag retrieves the value of a field by its tag type and value from a struct. Returns the field value and a boolean indicating if the field was found.

Types

This section is empty.

Jump to